'use strict';

/**
 * @typedef {import('./err.js').Serializer} Serializer
 */

/**
 * request serializer
 *
 * removes cookie values and authorization headers
 * @type {Serializer}
 * @param {object} [req] Request object
 * @returns {object}
 */
function reqSerializer(req) {
  if (typeof req !== 'object' || !req) return

  // eslint-disable-next-line no-unused-vars
  const { authorization, cookie, ...headers } = req.headers || {};

  const logReq = {
    id: typeof req.id === 'function' ? req.id() : req.id,
    method: req.method,
    url: req.originalUrl || req.url,
    remoteAddress: req.socket?.remoteAddress,
    remotePort: req.socket?.remotePort
  };
  if (Object.keys(headers).length) {
    logReq.headers = headers;
  }

  return logReq
}

exports.reqSerializer = reqSerializer;
