'use strict';

/**
 * @typedef {import('./err.js').Serializer} Serializer
 */

const startTimeKey = Symbol('startTime');

const SET_COOKIE = 'set-cookie';
const PROXY_AUTHENTICATE = 'proxy-authenticate';

/**
 * response serializer
 *
 * removes set-cookie and proxy-authenticate headers
 * @type {Serializer}
 * @param {object} [res] Response object
 * @returns {object}
 */
function resSerializer(res) {
  if (typeof res !== 'object' || !res) return

  /* eslint-disable no-unused-vars */
  const {
    [SET_COOKIE]: _1,
    [PROXY_AUTHENTICATE]: _2,
    ...headers
  } = res.getHeaders() || {};
  /* eslint-enable no-unused-vars */

  const logRes = {
    statusCode: res.statusCode
  };
  if (Object.keys(headers).length) {
    logRes.headers = headers;
  }
  if (res[startTimeKey]) {
    logRes.ms = Date.now() - res[startTimeKey];
  }

  return logRes
}

exports.resSerializer = resSerializer;
exports.startTimeKey = startTimeKey;
